#
# spec file for package gnu-recutils
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _lsover  1
%define _osover  0
Name:           gnu-recutils
Version:        1.7
Release:        lp150.1.4
Summary:        Text-based databases called recfiles
License:        GPL-3.0+
Group:          Productivity/Databases/Tools
URL:            https://www.gnu.org/software/recutils
Source0:        https://ftp.gnu.org/gnu/recutils/recutils-%{version}.tar.gz
Source1:        https://ftp.gnu.org/gnu/recutils/recutils-%{version}.tar.gz.sig
Source99:       %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM recutils-1.7-fix_implicit_declarations.patch -- aloisio@gmx.com
Patch0:         recutils-1.7-fix_implicit_declarations.patch
# PATCH-FIX-UPSTREAM recutils-1.7-fix_manpages.patch -- aloisio@gmx.com
Patch1:         recutils-1.7-fix_manpages.patch
# PATCH-FIX-UPSTREAM recutils-1.7-bash_includedirs.patch -- aloisio@gmx.com
Patch2:         recutils-1.7-bash_includedirs.patch
BuildRequires:  libacl-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  pkgconfig
%if 0%{?suse_version} > 1320
BuildRequires:  pkgconfig(bash)
%endif
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(libmdb)
BuildRequires:  pkgconfig(libselinux)
BuildRequires:  pkgconfig(uuid)
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}

%description
A set of tools and libraries to access human-editable, text-based
databases.

The data is stored as a sequence of records, each record containing
an arbitrary number of named fields.

Despite its simplicity, recfiles can be used to store medium-sized
databases.

%package        devel
Summary:        Header files for %{name} libraries
Group:          Development/Languages/C and C++
Requires:       librec%{_lsover} = %{version}
%if 0%{?suse_version} > 1320
Requires:       readrec%{_osover} = %{version}
Requires:       testrec%{_osover} = %{version}
%endif

%description    devel
This package contains files to develop for %{name} libraries

%package     -n librec%{_lsover}
Summary:        Text-based databases called recfiles
Group:          System/Libraries

%description -n librec%{_lsover}
A set of tools and libraries to access human-editable, text-based
databases.

The data is stored as a sequence of records, each record containing
an arbitrary number of named fields.

Despite its simplicity, recfiles can be used to store medium-sized
databases.

%if 0%{?suse_version} > 1320
%package     -n readrec%{_osover}
Summary:        Text-based databases called recfiles
Group:          System/Libraries

%description -n readrec%{_osover}
A set of tools and libraries to access human-editable, text-based
databases.

The data is stored as a sequence of records, each record containing
an arbitrary number of named fields.

Despite its simplicity, recfiles can be used to store medium-sized
databases.

%package     -n testrec%{_osover}
Summary:        Text-based databases called recfiles
Group:          System/Libraries

%description -n testrec%{_osover}
A set of tools and libraries to access human-editable, text-based
databases.

The data is stored as a sequence of records, each record containing
an arbitrary number of named fields.

Despite its simplicity, recfiles can be used to store medium-sized
databases.
%endif

%lang_package

%prep
%setup -q -n recutils-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang recutils %{name}.lang

%check
make check

%post
%install_info --info-dir=%{_infodir} %{_infodir}/recutils.info.gz

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/recutils.info.gz

%post   -n librec%{_lsover} -p /sbin/ldconfig
%postun -n librec%{_lsover} -p /sbin/ldconfig
%if 0%{?suse_version} > 1320
%post   -n readrec%{_osover} -p /sbin/ldconfig
%postun -n readrec%{_osover} -p /sbin/ldconfig
%post   -n testrec%{_osover} -p /sbin/ldconfig
%postun -n testrec%{_osover} -p /sbin/ldconfig
%endif

%files
%doc COPYING NEWS README
%dir %{_datadir}/recutils
%dir %{_datadir}/recutils%{_sysconfdir}
%{_bindir}/csv2rec
%{_bindir}/mdb2rec
%{_bindir}/rec2csv
%{_bindir}/recdel
%{_bindir}/recfix
%{_bindir}/recfmt
%{_bindir}/recinf
%{_bindir}/recins
%{_bindir}/recsel
%{_bindir}/recset
%{_datadir}/emacs/site-lisp/ob-rec.el
%{_datadir}/emacs/site-lisp/rec-mode.el
%{_infodir}/rec-mode.info%{ext_info}
%{_infodir}/recutils.info%{ext_info}
%{_mandir}/man1/csv2rec.1%{ext_man}
%{_mandir}/man1/mdb2rec.1%{ext_man}
%{_mandir}/man1/rec2csv.1%{ext_man}
%{_mandir}/man1/recdel.1%{ext_man}
%{_mandir}/man1/recfix.1%{ext_man}
%{_mandir}/man1/recfmt.1%{ext_man}
%{_mandir}/man1/recinf.1%{ext_man}
%{_mandir}/man1/recins.1%{ext_man}
%{_mandir}/man1/recsel.1%{ext_man}
%{_mandir}/man1/recset.1%{ext_man}
%{_datadir}/recutils%{_sysconfdir}/FSD.rec

%files devel
%{_includedir}/rec.h
%{_libdir}/librec.so
%if 0%{?suse_version} > 1320
%{_libdir}/readrec.so
%{_libdir}/testrec.so
%endif

%files -n librec%{_lsover}
%{_libdir}/librec.so.%{_lsover}*

%if 0%{?suse_version} > 1320
%files -n readrec%{_osover}
%{_libdir}/readrec.so.%{_osover}*

%files -n testrec%{_osover}
%{_libdir}/testrec.so.%{_osover}*
%endif

%files lang -f %{name}.lang

%changelog
* Sun Nov  5 2017 aloisio@gmx.com
- Initial package (v1.7)
